pub struct EnterStartResp {
pub state: EnterState,
pub nonce: EnterNonce,
}Expand description
What’s returned by EnterStartEP.
Fields
state: EnterStateOpaque state that needs to be send to the EnterCompleteEP later on
nonce: EnterNonceOpaque number used only once to be included in the hub pseudonym package.