HubMacKey

Struct HubMacKey 

pub struct HubMacKey {
    inner: B64UU<ByteArray<32>>,
}
Symmetric key to bind the hub id, but ‘blind’ the hub id from PHC.

The HubMacKey is randomly generated by the hub for each call to EnterStartEP, stored in the hub-encrypted EnterStartResp::state — which, unlike the EnterNonce, never transits the transcryptor or PHC — and returned to the global client via EnterStartResp::hub_mac_key. The global client relays it to the transcryptor via tr::EhppReq::hub_mac_key.

The transcryptor uses the HubMacKey to HMAC the hub id it pseudonymises for (see HubMacKey::mac). The mac is passed via the sso::EncryptedHubPseudonymPackage to PHC, which includes it in the sso::HashedHubPseudonymPackage that eventually ends up back at the hub, via EnterCompleteReq. The hub can then check the mac is indeed the mac of its own hub id, using the HubMacKey recovered from its state.

This HubMacKey is known to the hub and the global client, but must remain hidden from PHC.

Fields

inner: B64UU<ByteArray<32>>

Implementations

Source

impl HubMacKey

pub fn random() -> Self

Generates a new random key.

pub fn mac(&self, hub_id: &Id) -> Id

Macs a hub_id: returns HMAC-SHA256(self, hub_id), the hub id blinded so PHC can not see what hub is being visited.