pub struct InfoResp {
pub verifying_key: Option<VerifyingKeyBytes>,
pub hub_version: String,
pub hub_client_url: Url,
pub database_engine: DatabaseEngine,
pub dynamic: Option<DynamicHubInfo>,
}Fields
verifying_key: Option<VerifyingKeyBytes>Key used by the hub to sign requests to the other hubs with
(Not currently returned by actual hubs.)
hub_version: StringString describing the hub version, likely the result of git describe --tags
hub_client_url: UrlURL to this hub’s client
database_engine: DatabaseEngineThe database engine the hub is currently running on, which lets us track which hubs
have completed the sqlite3 -> postgres migration. Defaults to DatabaseEngine::Unknown
for hubs predating this field.
dynamic: Option<DynamicHubInfo>Changeable information about this hub.