pub struct InfoResp {
pub verifying_key: Option<VerifyingKey>,
pub hub_version: String,
pub hub_client_url: Url,
pub dynamic: Option<DynamicHubInfo>,
}Fields
verifying_key: Option<VerifyingKey>Key used by the hub to sign requests to the other hubs with
(Not currently returned by actual hubs.)
hub_version: StringString describing the hub version, likely the result of git describe --tags
hub_client_url: UrlURL to this hub’s client
dynamic: Option<DynamicHubInfo>Changeable information about this hub.